==> kdesvn-1.7.0.tar.xz: kdesvn-1.7.0/src/svnfrontend/models/svndirsortfilter.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by Rajko Albrecht  ral@alwins-world.de             *
 *   http://kdesvn.alwins-world.de/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#include "svndirsortfilter.h"
#include "svnitemnode.h"
#include "src/settings/kdesvnsettings.h"
#include <kdebug.h>

SvnDirSortFilterProxy::SvnDirSortFilterProxy(QObject *parent)
    : SvnSortFilterProxy(parent)
{
    setShowFilter(svnmodel::Dir);
}

SvnDirSortFilterProxy::~SvnDirSortFilterProxy()
{
}

int SvnDirSortFilterProxy::columnCount(const QModelIndex &parent)const
{
    Q_UNUSED(parent);
    return 1;
}

==> kdesvn_2.0.0.orig.tar.xz: kdesvn-2.0.0/src/svnfrontend/models/svndirsortfilter.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by Rajko Albrecht  ral@alwins-world.de             *
 *   http://kdesvn.alwins-world.de/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#include "svndirsortfilter.h"
#include "svnitemnode.h"
#include "settings/kdesvnsettings.h"

SvnDirSortFilterProxy::SvnDirSortFilterProxy(QObject *parent)
    : SvnSortFilterProxy(parent)
{
    setShowFilter(svnmodel::Dir);
}

SvnDirSortFilterProxy::~SvnDirSortFilterProxy()
{
}

int SvnDirSortFilterProxy::columnCount(const QModelIndex &parent)const
{
    Q_UNUSED(parent);
    return 1;
}
